#include <boost/math/special_functions/zeta.hpp>
#include "../boostmath/macros.hpp"

UNARY_BOOST_FUNCTION(zeta, double);
